summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit2db4a66b13dbbd08898c3199145ca7179c9c05b4 (patch)
tree8dc7ee9387ee7c82e0c4e56814d00149c65dce2f
parent3560fb4ba8b76c600d11e22fd817af9242f2525c (diff)
downloadkile-2db4a66b.tar.gz
kile-2db4a66b.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kile@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--src/kile/configcheckerwidget.ui2
-rw-r--r--src/kile/envconfigwidget.ui2
-rw-r--r--src/kile/generalconfigwidget.ui2
-rw-r--r--src/kile/graphicsconfigwidget.ui2
-rw-r--r--src/kile/helpconfigwidget.ui2
-rw-r--r--src/kile/kiledocmanager.cpp60
-rw-r--r--src/kile/kilegrepdialog.cpp2
-rw-r--r--src/kile/kileinfo.h2
-rw-r--r--src/kile/kilejscript.cpp2
-rw-r--r--src/kile/kilemultitabbar.cpp4
-rw-r--r--src/kile/kileprojectview.cpp4
-rw-r--r--src/kile/kileprojectview.h2
-rw-r--r--src/kile/kilestructurewidget.cpp14
-rw-r--r--src/kile/kilestructurewidget.h2
-rw-r--r--src/kile/kiletoolconfigwidget.cpp6
-rw-r--r--src/kile/latexcmddialog.cpp10
-rw-r--r--src/kile/latexconfigwidget.ui2
-rw-r--r--src/kile/latexoutputfilter.cpp6
-rw-r--r--src/kile/latextoolconfigwidget.ui2
-rw-r--r--src/kile/librarytoolconfigwidget.ui2
-rw-r--r--src/kile/newdocumentwidget.ui2
-rw-r--r--src/kile/newtoolwizard.ui4
-rw-r--r--src/kile/newtoolwizard.ui.h2
-rw-r--r--src/kile/processtoolconfigwidget.ui2
-rw-r--r--src/kile/quickdocumentdialog.cpp4
-rw-r--r--src/kile/quicktoolconfigwidget.ui2
-rw-r--r--src/kile/scriptingconfigwidget.ui2
-rw-r--r--src/kile/structureconfigwidget.ui2
-rw-r--r--src/kile/symbolviewconfig.ui2
-rw-r--r--src/kile/toolconfigwidget.ui2
30 files changed, 77 insertions, 77 deletions
diff --git a/src/kile/configcheckerwidget.ui b/src/kile/configcheckerwidget.ui
index 5dc3114..72f5bf3 100644
--- a/src/kile/configcheckerwidget.ui
+++ b/src/kile/configcheckerwidget.ui
@@ -104,7 +104,7 @@
<function specifier="non virtual" returnType="TQLabel *">label()</function>
<function specifier="non virtual" returnType="KListBox *">listBox()</function>
</functions>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kprogress.h</includehint>
<includehint>klistbox.h</includehint>
diff --git a/src/kile/envconfigwidget.ui b/src/kile/envconfigwidget.ui
index da30fd4..c04e09b 100644
--- a/src/kile/envconfigwidget.ui
+++ b/src/kile/envconfigwidget.ui
@@ -168,5 +168,5 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/src/kile/generalconfigwidget.ui b/src/kile/generalconfigwidget.ui
index 99fb772..1d74db9 100644
--- a/src/kile/generalconfigwidget.ui
+++ b/src/kile/generalconfigwidget.ui
@@ -239,7 +239,7 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/src/kile/graphicsconfigwidget.ui b/src/kile/graphicsconfigwidget.ui
index c3b76b0..eeaa454 100644
--- a/src/kile/graphicsconfigwidget.ui
+++ b/src/kile/graphicsconfigwidget.ui
@@ -127,7 +127,7 @@
<function access="private" specifier="non virtual">init()</function>
<function specifier="non virtual">setLatexCommands( KConfig * config, KileDocument::LatexCommands * commands )</function>
</functions>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
</includehints>
diff --git a/src/kile/helpconfigwidget.ui b/src/kile/helpconfigwidget.ui
index f6d7699..340378b 100644
--- a/src/kile/helpconfigwidget.ui
+++ b/src/kile/helpconfigwidget.ui
@@ -171,7 +171,7 @@
<functions>
<function specifier="non virtual">setHelp( KileHelp::Help * help )</function>
</functions>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
</includehints>
diff --git a/src/kile/kiledocmanager.cpp b/src/kile/kiledocmanager.cpp
index 8acc06c..b57bb7c 100644
--- a/src/kile/kiledocmanager.cpp
+++ b/src/kile/kiledocmanager.cpp
@@ -86,7 +86,7 @@ Manager::Manager(KileInfo *info, TQObject *tqparent, const char *name) :
if ( KileConfig::defaultEncoding() == "invalid" )
KileConfig::setDefaultEncoding(TQString::tqfromLatin1(TQTextCodec::codecForLocale()->name()));
- TQWidget *par = m_ki ? m_ki->tqparentWidget() : 0;
+ TQWidget *par = m_ki ? m_ki->parentWidget() : 0;
m_kpd = new KProgressDialog(par, 0, i18n("Open Project..."), TQString(), true);
m_kpd->showCancelButton(false);
m_kpd->setLabel(i18n("Scanning project files..."));
@@ -483,8 +483,8 @@ Kate::Document* Manager::createDocument(const TQString& name, const KURL& url, T
doc->setDocName(name.isEmpty() ? url.fileName() : name);
//handle changes of the document
- connect(doc, TQT_SIGNAL(nameChanged(Kate::Document *)), m_ki->tqparentWidget(), TQT_SLOT(newCaption()));
- connect(doc, TQT_SIGNAL(fileNameChanged()), m_ki->tqparentWidget(), TQT_SLOT(newCaption()));
+ connect(doc, TQT_SIGNAL(nameChanged(Kate::Document *)), m_ki->parentWidget(), TQT_SLOT(newCaption()));
+ connect(doc, TQT_SIGNAL(fileNameChanged()), m_ki->parentWidget(), TQT_SLOT(newCaption()));
connect(doc, TQT_SIGNAL(modStateChanged(Kate::Document*)), this, TQT_SLOT(newDocumenttqStatus(Kate::Document*)));
connect(doc, TQT_SIGNAL(modifiedOnDisc(Kate::Document*, bool, unsigned char)), this, TQT_SIGNAL(documentStatusChanged(Kate::Document*, bool, unsigned char)));
@@ -569,7 +569,7 @@ Kate::View* Manager::loadTemplate(TemplateItem *sel)
if (!tempdoc->openURL(KURL(sel->path())))
{
- KMessageBox::error(m_ki->tqparentWidget(), i18n("Could not find template: %1").tqarg(sel->name()),i18n("File Not Found"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("Could not find template: %1").tqarg(sel->name()),i18n("File Not Found"));
}
else
{
@@ -629,13 +629,13 @@ void Manager::createTemplate()
{
if (view->getDoc()->isModified() )
{
- KMessageBox::information(m_ki->tqparentWidget(),i18n("Please save the file first."));
+ KMessageBox::information(m_ki->parentWidget(),i18n("Please save the file first."));
return;
}
}
else
{
- KMessageBox::information(m_ki->tqparentWidget(),i18n("Open/create a document first."));
+ KMessageBox::information(m_ki->parentWidget(),i18n("Open/create a document first."));
return;
}
@@ -644,7 +644,7 @@ void Manager::createTemplate()
if(type == KileDocument::Undefined || type == KileDocument::Text)
{
- KMessageBox::information(m_ki->tqparentWidget(),i18n("Sorry, but a template for this type of document cannot be created."));
+ KMessageBox::information(m_ki->parentWidget(),i18n("Sorry, but a template for this type of document cannot be created."));
return;
}
@@ -660,7 +660,7 @@ void Manager::removeTemplate()
void Manager::fileNew()
{
- NewFileWizard *nfw = new NewFileWizard(m_ki->templateManager(), m_ki->tqparentWidget());
+ NewFileWizard *nfw = new NewFileWizard(m_ki->templateManager(), m_ki->parentWidget());
if (nfw->exec())
{
loadTemplate(nfw->getSelection());
@@ -700,7 +700,7 @@ void Manager::fileOpen()
+ "*|" + i18n("All Files");
//get the URLs
- KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenURLsAndEncoding( KileConfig::defaultEncoding(), currentDir, filter, m_ki->tqparentWidget(), i18n("Open Files") );
+ KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenURLsAndEncoding( KileConfig::defaultEncoding(), currentDir, filter, m_ki->parentWidget(), i18n("Open Files") );
//open them
KURL::List urls = result.URLs;
@@ -923,7 +923,7 @@ void Manager::fileSaveAs(Kate::View* view)
while(true)
{
TQString filter = info->getFileFilter() + "\n* |" + i18n("All Files");
- result = KEncodingFileDialog::getSaveURLAndEncoding(KileConfig::defaultEncoding(), startURL.url(), filter, m_ki->tqparentWidget(), i18n("Save File"));
+ result = KEncodingFileDialog::getSaveURLAndEncoding(KileConfig::defaultEncoding(), startURL.url(), filter, m_ki->parentWidget(), i18n("Save File"));
if(result.URLs.isEmpty() || result.URLs.first().isEmpty())
{
return;
@@ -934,7 +934,7 @@ void Manager::fileSaveAs(Kate::View* view)
}
if(KIO::NetAccess::exists(saveURL, true, kapp->mainWidget())) // check for writing possibility
{
- int r = KMessageBox::warningContinueCancel(m_ki->tqparentWidget(), i18n("A file with the name \"%1\" exists already. Do you want to overwrite it ?").tqarg(saveURL.fileName()), i18n("Overwrite File ?"), KGuiItem(i18n("&Overwrite")), TQString());
+ int r = KMessageBox::warningContinueCancel(m_ki->parentWidget(), i18n("A file with the name \"%1\" exists already. Do you want to overwrite it ?").tqarg(saveURL.fileName()), i18n("Overwrite File ?"), KGuiItem(i18n("&Overwrite")), TQString());
if(r != KMessageBox::Continue)
{
continue;
@@ -1108,13 +1108,13 @@ void Manager::buildProjectTree(KileProject *project)
project->buildProjectTree();
}
else if (m_projects.count() == 0)
- KMessageBox::error(m_ki->tqparentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to build the tree for, then choose Refresh Project Tree again."),i18n( "Could Not Refresh Project Tree"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to build the tree for, then choose Refresh Project Tree again."),i18n( "Could Not Refresh Project Tree"));
}
void Manager::projectNew()
{
KILE_DEBUG() << "==Kile::projectNew==========================" << endl;
- KileNewProjectDlg *dlg = new KileNewProjectDlg(m_ki->templateManager(), m_ki->extensions(), m_ki->tqparentWidget());
+ KileNewProjectDlg *dlg = new KileNewProjectDlg(m_ki->templateManager(), m_ki->extensions(), m_ki->parentWidget());
KILE_DEBUG()<< "\tdialog created" << endl;
if (dlg->exec())
@@ -1188,7 +1188,7 @@ KileProject* Manager::selectProject(const TQString& caption)
TQString name = TQString();
if (list.count() > 1)
{
- KileListSelector *dlg = new KileListSelector(list, caption, i18n("Select Project"), m_ki->tqparentWidget());
+ KileListSelector *dlg = new KileListSelector(list, caption, i18n("Select Project"), m_ki->parentWidget());
if (dlg->exec())
{
name = list[dlg->currentItem()];
@@ -1248,7 +1248,7 @@ void Manager::removeFromProject(const KileProjectItem *item)
if (item->project()->url() == item->url())
{
- KMessageBox::error(m_ki->tqparentWidget(), i18n("This file is the project file, it holds all the information about your project. Therefore it is not allowed to remove this file from its project."), i18n("Cannot Remove File From Project"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("This file is the project file, it holds all the information about your project. Therefore it is not allowed to remove this file from its project."), i18n("Cannot Remove File From Project"));
return;
}
@@ -1278,7 +1278,7 @@ void Manager::projectOpenItem(KileProjectItem *item, bool openProjectItemViews)
else if (view != 0L)
view->setCursorPosition(item->lineNumber(), item->columnNumber());
- //oops, doc aptqparently was open while the project settings wants it closed, don't trash it the doc, update openstate instead
+ //oops, doc apparently was open while the project settings wants it closed, don't trash it the doc, update openstate instead
if ((!item->isOpen()) && (view != 0L))
item->setOpenState(true);
}
@@ -1294,7 +1294,7 @@ KileProject* Manager::projectOpen(const KURL & url, int step, int max, bool open
{
m_kpd->cancel();
- KMessageBox::information(m_ki->tqparentWidget(), i18n("The project you tried to open is already opened. If you wanted to reload the project, close the project before you re-open it."),i18n("Project Already Open"));
+ KMessageBox::information(m_ki->parentWidget(), i18n("The project you tried to open is already opened. If you wanted to reload the project, close the project before you re-open it."),i18n("Project Already Open"));
return 0L;
}
@@ -1303,7 +1303,7 @@ KileProject* Manager::projectOpen(const KURL & url, int step, int max, bool open
{
m_kpd->cancel();
- if (KMessageBox::warningYesNo(m_ki->tqparentWidget(), i18n("The project file for this project does not exists or is not readable. Remove this project from the recent projects list?"),i18n("Could Not Load Project File")) == KMessageBox::Yes)
+ if (KMessageBox::warningYesNo(m_ki->parentWidget(), i18n("The project file for this project does not exists or is not readable. Remove this project from the recent projects list?"),i18n("Could Not Load Project File")) == KMessageBox::Yes)
emit(removeFromRecentProjects(realurl));
return 0L;
@@ -1401,7 +1401,7 @@ void Manager::updateProjectReferences(KileProject *project)
KileProject* Manager::projectOpen()
{
KILE_DEBUG() << "==Kile::projectOpen==========================" << endl;
- KURL url = KFileDialog::getOpenURL( KileConfig::defaultProjectLocation(), i18n("*.kilepr|Kile Project Files\n*|All Files"), m_ki->tqparentWidget(), i18n("Open Project") );
+ KURL url = KFileDialog::getOpenURL( KileConfig::defaultProjectLocation(), i18n("*.kilepr|Kile Project Files\n*|All Files"), m_ki->parentWidget(), i18n("Open Project") );
if (!url.isEmpty())
return projectOpen(url);
@@ -1477,7 +1477,7 @@ void Manager::projectSave(KileProject *project /* = 0 */)
project->save();
}
else
- KMessageBox::error(m_ki->tqparentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to save, then choose Save Project again."),i18n( "Could Determine Active Project"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to save, then choose Save Project again."),i18n( "Could Determine Active Project"));
}
void Manager::projectAddFiles(const KURL & url)
@@ -1506,7 +1506,7 @@ void Manager::projectAddFiles(KileProject *project,const KURL & fileUrl)
currentDir=fileUrl.directory();
KILE_DEBUG() << "currentDir is " << currentDir << endl;
- KFileDialog *dlg = new KFileDialog(currentDir, i18n("*|All Files"),m_ki->tqparentWidget(), 0, true );
+ KFileDialog *dlg = new KFileDialog(currentDir, i18n("*|All Files"),m_ki->parentWidget(), 0, true );
KPushButton* okButton = dlg->okButton();
okButton->setText(i18n("Add"));
dlg->setCaption(i18n("Add Files"));
@@ -1528,7 +1528,7 @@ void Manager::projectAddFiles(KileProject *project,const KURL & fileUrl)
//open them
}
else if (m_projects.count() == 0)
- KMessageBox::error(m_ki->tqparentWidget(), i18n("There are no projects opened. Please open the project you want to add files to, then choose Add Files again."),i18n( "Could Not Determine Active Project"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("There are no projects opened. Please open the project you want to add files to, then choose Add Files again."),i18n( "Could Not Determine Active Project"));
}
void Manager::toggleArchive(KileProjectItem *item)
@@ -1556,11 +1556,11 @@ void Manager::projectOptions(KileProject *project /* = 0*/)
if (project)
{
KILE_DEBUG() << "\t" << project->name() << endl;
- KileProjectOptionsDlg *dlg = new KileProjectOptionsDlg(project, m_ki->extensions(), m_ki->tqparentWidget());
+ KileProjectOptionsDlg *dlg = new KileProjectOptionsDlg(project, m_ki->extensions(), m_ki->parentWidget());
dlg->exec();
}
else if (m_projects.count() == 0)
- KMessageBox::error(m_ki->tqparentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to modify, then choose Project Options again."),i18n( "Could Not Determine Active Project"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to modify, then choose Project Options again."),i18n( "Could Not Determine Active Project"));
}
bool Manager::projectCloseAll()
@@ -1647,7 +1647,7 @@ bool Manager::projectClose(const KURL & url)
return false;
}
else if (m_projects.count() == 0)
- KMessageBox::error(m_ki->tqparentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to close, then choose Close Project again."),i18n( "Could Not Close Project"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("The current document is not associated to a project. Please activate a document that is associated to the project you want to close, then choose Close Project again."),i18n( "Could Not Close Project"));
return true;
}
@@ -1700,7 +1700,7 @@ void Manager::cleanUpTempFiles(const KURL &url, bool silent)
if (!silent && extlist.count() > 0 )
{
KILE_DEBUG() << "not silent" << endl;
- KileDialog::Clean *dialog = new KileDialog::Clean(m_ki->tqparentWidget(), fileName, extlist);
+ KileDialog::Clean *dialog = new KileDialog::Clean(m_ki->parentWidget(), fileName, extlist);
if ( dialog->exec() )
extlist = dialog->getCleanlist();
else
@@ -1916,14 +1916,14 @@ KileProjectItem* Manager::selectProjectFileItem(const TQString &label)
// select one of these files
KileProjectItem *item = 0L;
- KileListSelector *dlg = new KileListSelector(filelist,i18n("Project Files"),label, m_ki->tqparentWidget());
+ KileListSelector *dlg = new KileListSelector(filelist,i18n("Project Files"),label, m_ki->parentWidget());
if ( dlg->exec() ) {
if ( dlg->currentItem() >= 0 ) {
TQString name = filelist[dlg->currentItem()];
if ( map.tqcontains(name) )
item = map[name];
else
- KMessageBox::error(m_ki->tqparentWidget(), i18n("Could not determine the selected file."),i18n( "Project Error"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("Could not determine the selected file."),i18n( "Project Error"));
}
}
delete dlg;
@@ -1949,7 +1949,7 @@ KileProjectItemList* Manager::selectProjectFileItems(const TQString &label)
KileProjectItemList *items = new KileProjectItemList();
items->setAutoDelete(false);
- KileListSelectorMultiple *dlg = new KileListSelectorMultiple(filelist,i18n("Project Files"),label, m_ki->tqparentWidget());
+ KileListSelectorMultiple *dlg = new KileListSelectorMultiple(filelist,i18n("Project Files"),label, m_ki->parentWidget());
if ( dlg->exec() ) {
if ( dlg->currentItem() >= 0 ) {
selectedfiles = dlg->selected();
@@ -1957,7 +1957,7 @@ KileProjectItemList* Manager::selectProjectFileItems(const TQString &label)
if ( map.tqcontains(*it) )
items->append( map[(*it)] );
else
- KMessageBox::error(m_ki->tqparentWidget(), i18n("Could not determine the selected file."),i18n( "Project Error"));
+ KMessageBox::error(m_ki->parentWidget(), i18n("Could not determine the selected file."),i18n( "Project Error"));
}
}
}
diff --git a/src/kile/kilegrepdialog.cpp b/src/kile/kilegrepdialog.cpp
index 3a73412..bfb4695 100644
--- a/src/kile/kilegrepdialog.cpp
+++ b/src/kile/kilegrepdialog.cpp
@@ -547,7 +547,7 @@ void KileGrepDialog::childExited()
if ( ! errbuf.isEmpty() )
{
- KMessageBox::information( tqparentWidget(),
+ KMessageBox::information( parentWidget(),
i18n("<strong>Error:</strong><p>") + errbuf,
i18n("Grep Tool Error") );
errbuf.truncate(0);
diff --git a/src/kile/kileinfo.h b/src/kile/kileinfo.h
index b168daf..011c539 100644
--- a/src/kile/kileinfo.h
+++ b/src/kile/kileinfo.h
@@ -133,7 +133,7 @@ public:
KileFileSelect* fileSelector() const { return m_fileSelector; }
KileEventFilter* eventFilter() const { return m_eventFilter; }
- TQWidget *tqparentWidget() const { return m_parentWidget; }
+ TQWidget *parentWidget() const { return m_parentWidget; }
static TQString expandEnvironmentVars(const TQString &variable);
static TQString checkOtherPaths(const TQString &path,const TQString &file, int type);
diff --git a/src/kile/kilejscript.cpp b/src/kile/kilejscript.cpp
index 42262a6..e478d6c 100644
--- a/src/kile/kilejscript.cpp
+++ b/src/kile/kilejscript.cpp
@@ -698,7 +698,7 @@ m_kileInfo->viewManager()->currentView()->down();*/
// watching of directories out of the box.
addDirectoryToDirWatch(*i);
}
- //we do not remove the directories that were once added as this aptqparently causes some strange
+ //we do not remove the directories that were once added as this apparently causes some strange
//bugs (on KDE 3.5.x)
}
diff --git a/src/kile/kilemultitabbar.cpp b/src/kile/kilemultitabbar.cpp
index 09b2ad2..0c86c3e 100644
--- a/src/kile/kilemultitabbar.cpp
+++ b/src/kile/kilemultitabbar.cpp
@@ -464,13 +464,13 @@ void KileMultiTabBarButton::setStyle(KileMultiTabBar::KileMultiTabBarStyle style
void KileMultiTabBarButton::hideEvent( TQHideEvent* he) {
TQPushButton::hideEvent(he);
- KileMultiTabBar *tb=dynamic_cast<KileMultiTabBar*>(tqparentWidget());
+ KileMultiTabBar *tb=dynamic_cast<KileMultiTabBar*>(parentWidget());
if (tb) tb->updateSeparator();
}
void KileMultiTabBarButton::showEvent( TQShowEvent* he) {
TQPushButton::showEvent(he);
- KileMultiTabBar *tb=dynamic_cast<KileMultiTabBar*>(tqparentWidget());
+ KileMultiTabBar *tb=dynamic_cast<KileMultiTabBar*>(parentWidget());
if (tb) tb->updateSeparator();
}
diff --git a/src/kile/kileprojectview.cpp b/src/kile/kileprojectview.cpp
index 44d4b5a..0d9e9b4 100644
--- a/src/kile/kileprojectview.cpp
+++ b/src/kile/kileprojectview.cpp
@@ -358,7 +358,7 @@ void KileProjectView::makeTheConnection(KileProjectViewItem *item)
KileProjectViewItem* KileProjectView::folder(const KileProjectItem *pi, KileProjectViewItem *item)
{
- KileProjectViewItem *tqparent = tqparentFor(pi, item);
+ KileProjectViewItem *tqparent = parentFor(pi, item);
if (tqparent == 0)
{
@@ -469,7 +469,7 @@ KileProjectViewItem * KileProjectView::itemFor(const KURL & url)
return item;
}
-KileProjectViewItem* KileProjectView::tqparentFor(const KileProjectItem *projitem, KileProjectViewItem *projvi)
+KileProjectViewItem* KileProjectView::parentFor(const KileProjectItem *projitem, KileProjectViewItem *projvi)
{
//find tqparent projectviewitem of projitem
KileProjectItem *parpi = projitem->tqparent();
diff --git a/src/kile/kileprojectview.h b/src/kile/kileprojectview.h
index 315e2db..d7fea71 100644
--- a/src/kile/kileprojectview.h
+++ b/src/kile/kileprojectview.h
@@ -141,7 +141,7 @@ public:
KileProjectViewItem* projectViewItemFor(const KURL &);
KileProjectViewItem* itemFor(const KURL &);
- KileProjectViewItem* tqparentFor(const KileProjectItem *projitem, KileProjectViewItem *projvi);
+ KileProjectViewItem* parentFor(const KileProjectItem *projitem, KileProjectViewItem *projvi);
protected:
virtual bool acceptDrag(TQDropEvent *e) const;
diff --git a/src/kile/kilestructurewidget.h b/src/kile/kilestructurewidget.h
index dc8f53c..7584719 100644
--- a/src/kile/kilestructurewidget.h
+++ b/src/kile/kilestructurewidget.h
@@ -139,7 +139,7 @@ namespace KileWidget
void slotConfigChanged();
private:
- KileListViewItem *tqparentFor(int lev, const TQString & fldr);
+ KileListViewItem *parentFor(int lev, const TQString & fldr);
void init();
KileListViewItem* createFolder(const TQString &folder);
diff --git a/src/kile/kiletoolconfigwidget.cpp b/src/kile/kiletoolconfigwidget.cpp
index 46324f5..7594716 100644
--- a/src/kile/kiletoolconfigwidget.cpp
+++ b/src/kile/kiletoolconfigwidget.cpp
@@ -375,14 +375,14 @@ namespace KileWidget
if (ntw->exec())
{
TQString toolName = ntw->toolName();
- TQString tqparentTool = ntw->tqparentTool();
+ TQString parentTool = ntw->parentTool();
writeStdConfig(toolName, "Default");
- if ( tqparentTool != ntw->customTool() )
+ if ( parentTool != ntw->customTool() )
{
//copy tool info
KileTool::Config tempMap;
- m_manager->retrieveEntryMap(tqparentTool, tempMap, false, false);
+ m_manager->retrieveEntryMap(parentTool, tempMap, false, false);
m_config->setGroup(KileTool::groupFor(toolName, "Default"));
m_config->writeEntry("class", tempMap["class"]);
m_config->writeEntry("type", tempMap["type"]);
diff --git a/src/kile/latexcmddialog.cpp b/src/kile/latexcmddialog.cpp
index b56dda9..fe37e76 100644
--- a/src/kile/latexcmddialog.cpp
+++ b/src/kile/latexcmddialog.cpp
@@ -713,11 +713,11 @@ void LatexCommandsDialog::slotEditClicked()
KListViewItem *item = (KListViewItem *)listview->selectedItem();
if ( item && !isParentItem(item) )
{
- KListViewItem *tqparentitem = (KListViewItem *)item->tqparent();
- if ( tqparentitem )
+ KListViewItem *parentitem = (KListViewItem *)item->tqparent();
+ if ( parentitem )
{
// get current command type
- KileDocument::CmdAttribute type = getCommandMode(tqparentitem);
+ KileDocument::CmdAttribute type = getCommandMode(parentitem);
if ( type == KileDocument::CmdAttrNone )
{
KILE_DEBUG() << "\tLatexCommandsDialog error: no item in slotAddClicked() (" << item->text(0) << ")" << endl;
@@ -725,7 +725,7 @@ void LatexCommandsDialog::slotEditClicked()
}
// edit a new environment or command
- NewLatexCommand *dialog = new NewLatexCommand(this,caption,tqparentitem->text(0),item,type, &m_dictCommands);
+ NewLatexCommand *dialog = new NewLatexCommand(this,caption,parentitem->text(0),item,type, &m_dictCommands);
if ( dialog->exec() == TQDialog::Accepted )
{
m_commandChanged = true;
@@ -736,7 +736,7 @@ void LatexCommandsDialog::slotEditClicked()
TQString name;
KileDocument::LatexCmdAttributes attr;
dialog->getParameter(name,attr);
- setEntry(tqparentitem,name,attr);
+ setEntry(parentitem,name,attr);
}
delete dialog;
}
diff --git a/src/kile/latexconfigwidget.ui b/src/kile/latexconfigwidget.ui
index 836a835..a162c66 100644
--- a/src/kile/latexconfigwidget.ui
+++ b/src/kile/latexconfigwidget.ui
@@ -249,7 +249,7 @@
<function access="private" specifier="non virtual">init()</function>
<function specifier="non virtual">setLatexCommands( KConfig * config, KileDocument::LatexCommands * commands )</function>
</functions>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/src/kile/latexoutputfilter.cpp b/src/kile/latexoutputfilter.cpp
index 17f2008..9c24d2d 100644
--- a/src/kile/latexoutputfilter.cpp
+++ b/src/kile/latexoutputfilter.cpp
@@ -91,11 +91,11 @@ bool LatexOutputFilter::fileExists(const TQString & name)
// 2) Since people will probably also use the \input command, we also have to be
// to detect the old-fashioned way. TeX prints '(filename' when opening a file and a ')'
// when closing one. It is impossible to detect this with 100% certainty (TeX prints many messages
-// and even text (a context) from the TeX source file, there could be unbalanced tqparentheses),
+// and even text (a context) from the TeX source file, there could be unbalanced parentheses),
// so we use a heuristic algorithm. In heuristic mode a ')' will only be considered as a signal that
// TeX is closing a file if the top of the stack is not marked as "reliable".
// Also, when scanning for a TeX error linenumber (which sometimes causes a context to be printed
-// to the log-file), updateFileStack is not called, helping not to pick up unbalanced tqparentheses
+// to the log-file), updateFileStack is not called, helping not to pick up unbalanced parentheses
// from the context.
void LatexOutputFilter::updateFileStack(const TQString &strLine, short & dwCookie)
{
@@ -183,7 +183,7 @@ void LatexOutputFilter::updateFileStackHeuristic(const TQString &strLine, short
dwCookie = Start;
}
- //scan for tqparentheses and grab filenames
+ //scan for parentheses and grab filenames
for (unsigned int i = 0; i < strLine.length(); ++i) {
//We're expecting a filename. If a filename really ends at this position one of the following must be true:
// 1) Next character is a space (indicating the end of a filename (yes, there can't spaces in the
diff --git a/src/kile/latextoolconfigwidget.ui b/src/kile/latextoolconfigwidget.ui
index 296d649..b320fc8 100644
--- a/src/kile/latextoolconfigwidget.ui
+++ b/src/kile/latextoolconfigwidget.ui
@@ -53,5 +53,5 @@
</widget>
</vbox>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/src/kile/librarytoolconfigwidget.ui b/src/kile/librarytoolconfigwidget.ui
index 13d8c14..8c5ba70 100644
--- a/src/kile/librarytoolconfigwidget.ui
+++ b/src/kile/librarytoolconfigwidget.ui
@@ -100,5 +100,5 @@
</spacer>
</grid>
</widget>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/src/kile/newdocumentwidget.ui b/src/kile/newdocumentwidget.ui
index 290ecb6..ce4cea1 100644
--- a/src/kile/newdocumentwidget.ui
+++ b/src/kile/newdocumentwidget.ui
@@ -122,5 +122,5 @@
</sizepolicy>
</customwidget>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/src/kile/newtoolwizard.ui b/src/kile/newtoolwizard.ui
index 2f30ab6..52eb717 100644
--- a/src/kile/newtoolwizard.ui
+++ b/src/kile/newtoolwizard.ui
@@ -179,9 +179,9 @@ the standard "LaTeX" tool.</string>
<function access="private" specifier="non virtual">init()</function>
<function returnType="TQString">customTool()</function>
<function returnType="TQString">toolName()</function>
- <function returnType="TQString">tqparentTool()</function>
+ <function returnType="TQString">parentTool()</function>
</functions>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>kcombobox.h</includehint>
diff --git a/src/kile/newtoolwizard.ui.h b/src/kile/newtoolwizard.ui.h
index 72f5c00..9137bac 100644
--- a/src/kile/newtoolwizard.ui.h
+++ b/src/kile/newtoolwizard.ui.h
@@ -44,7 +44,7 @@ TQString NewToolWizard::toolName()
return m_leName->text();
}
-TQString NewToolWizard::tqparentTool()
+TQString NewToolWizard::parentTool()
{
return m_cbTools->currentText();
}
diff --git a/src/kile/processtoolconfigwidget.ui b/src/kile/processtoolconfigwidget.ui
index 6502764..02595c7 100644
--- a/src/kile/processtoolconfigwidget.ui
+++ b/src/kile/processtoolconfigwidget.ui
@@ -94,5 +94,5 @@
</spacer>
</grid>
</widget>
-<tqlayoutdefaults spacing="11" margin="11"/>
+<layoutdefaults spacing="11" margin="11"/>
</UI>
diff --git a/src/kile/quickdocumentdialog.cpp b/src/kile/quickdocumentdialog.cpp
index e23dd0d..4a862fa 100644
--- a/src/kile/quickdocumentdialog.cpp
+++ b/src/kile/quickdocumentdialog.cpp
@@ -2096,8 +2096,8 @@ void QuickDocument::slotCheckParent(TQListViewItem *listViewItem)
void QuickDocument::slotPackageDoubleClicked(TQListViewItem *listViewItem,const TQPoint &,int)
{
if ( listViewItem && listViewItem->tqparent() ) {
- TQCheckListItem *tqparentitem = dynamic_cast<TQCheckListItem*>(listViewItem->tqparent());
- TQString option = tqparentitem->text(0) + '!' + listViewItem->text(0);
+ TQCheckListItem *parentitem = dynamic_cast<TQCheckListItem*>(listViewItem->tqparent());
+ TQString option = parentitem->text(0) + '!' + listViewItem->text(0);
if ( m_dictPackagesEditable.tqcontains(option) )
slotPackageEdit();
}
diff --git a/src/kile/quicktoolconfigwidget.ui b/src/kile/quicktoolconfigwidget.ui
index d5c4a07..a3de889 100644
--- a/src/kile/quicktoolconfigwidget.ui
+++ b/src/kile/quicktoolconfigwidget.ui
@@ -214,5 +214,5 @@
<slot access="private" specifier="non virtual">add()</slot>
<slot access="private" specifier="non virtual">changed()</slot>
</Q_SLOTS>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/src/kile/scriptingconfigwidget.ui b/src/kile/scriptingconfigwidget.ui
index d18a8fb..70874c4 100644
--- a/src/kile/scriptingconfigwidget.ui
+++ b/src/kile/scriptingconfigwidget.ui
@@ -211,7 +211,7 @@
<includes>
<include location="local" impldecl="in implementation">scriptingconfigwidget.ui.h</include>
</includes>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/src/kile/structureconfigwidget.ui b/src/kile/structureconfigwidget.ui
index bcad803..a5d8474 100644
--- a/src/kile/structureconfigwidget.ui
+++ b/src/kile/structureconfigwidget.ui
@@ -337,7 +337,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/src/kile/symbolviewconfig.ui b/src/kile/symbolviewconfig.ui
index 8066a43..4f785cd 100644
--- a/src/kile/symbolviewconfig.ui
+++ b/src/kile/symbolviewconfig.ui
@@ -134,7 +134,7 @@
<tabstop>kcfg_displayMFUS</tabstop>
<tabstop>kcfg_clearMFUS</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/src/kile/toolconfigwidget.ui b/src/kile/toolconfigwidget.ui
index 59bb2f6..0bb1cf2 100644
--- a/src/kile/toolconfigwidget.ui
+++ b/src/kile/toolconfigwidget.ui
@@ -623,5 +623,5 @@
<tabstop>m_leRelDir</tabstop>
<tabstop>m_cbMenu</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/src/kile/kilestructurewidget.cpp b/src/kile/kilestructurewidget.cpp
index b3205a6..72349ff 100644
--- a/src/kile/kilestructurewidget.cpp
+++ b/src/kile/kilestructurewidget.cpp
@@ -366,7 +366,7 @@ namespace KileWidget
m_stack->raiseWidget(this);
}
- KileListViewItem *StructureList::tqparentFor(int lev, const TQString & fldr)
+ KileListViewItem *StructureList::parentFor(int lev, const TQString & fldr)
{
KileListViewItem *par = 0L;
@@ -505,8 +505,8 @@ namespace KileWidget
m_lastLine = line;
//find the tqparent for the new element
- KileListViewItem *tqparentItem = ( type==KileStruct::BeamerBeginBlock && m_lastFrameEnv ) ? m_lastFrameEnv : tqparentFor(lev, fldr);
- if ( tqparentItem == 0L )
+ KileListViewItem *parentItem = ( type==KileStruct::BeamerBeginBlock && m_lastFrameEnv ) ? m_lastFrameEnv : parentFor(lev, fldr);
+ if ( parentItem == 0L )
{
KMessageBox::error(0,i18n("Can't create ListviewItem: no tqparent found."));
return;
@@ -514,7 +514,7 @@ namespace KileWidget
//find the last element at this level
KileListViewItem *lastChild = 0L;
- KileListViewItem *nextChild = (KileListViewItem *)tqparentItem->firstChild();
+ KileListViewItem *nextChild = (KileListViewItem *)parentItem->firstChild();
while ( nextChild )
{
lastChild = nextChild;
@@ -522,14 +522,14 @@ namespace KileWidget
}
// create a new item
- KileListViewItem *newChild = new KileListViewItem(tqparentItem, lastChild, title, m_docinfo->url(), line, column, type, lev, startline, startcol);
+ KileListViewItem *newChild = new KileListViewItem(parentItem, lastChild, title, m_docinfo->url(), line, column, type, lev, startline, startcol);
if ( ! pix.isNull() )
newChild->setPixmap(0,SmallIcon(pix));
//m_stop = true;
//if the level is not greater than the defaultLevel
- //open the tqparentItem to make this item visible
- tqparentItem->setOpen( shouldBeOpen(tqparentItem,fldr,lev) );
+ //open the parentItem to make this item visible
+ parentItem->setOpen( shouldBeOpen(parentItem,fldr,lev) );
//update the m_parent levels, such that section etc. get inserted at the correct level
//m_current = newChild;